<?php
namespace App\Http\Controllers\AdminControllers;


use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Web\Index;
use App\Models\Core\Images;
use App\Models\Core\Posts;
use App\Models\Core\Posttypes;
use App\Models\Core\Postmeta;
use App\Models\Core\Taxonomy;
use App\Models\Core\Terms;
use App\Models\Core\TermRelations;

class PostsController extends Controller
{
   
    
	public function view(Request $request){
		
		$data ['post_type_data'] = Posts::where('post_type' , $request->post_type )->orderBy('ID','DESC')
									->get();

		$title = Posttypes::where('post_type' , $request->post_type )->first();

		$data['post_type'] = ['type' => $request->post_type , 'title' => $title->post_type_title ];

	 	$data['taxonomy'] = Taxonomy::exists($request->post_type);

		$title = array('pageTitle' => $title->post_type_title );

		return view("admin.posts.index",$title)->with('data', $data);
	}


	public function add(Request $request){
		
		$title = Posttypes::where('post_type' , $request->post_type )->first();

		$data['post_type'] = ['type' => $request->post_type , 'title' => $title->post_type_title ];

		$checktax = Taxonomy::exists($request->post_type);

		$data['taxonomy'] = Terms::get_terms($checktax);

		$title = array('pageTitle' => 'Add '.$title->post_type_title );

		return view("admin.posts.add",$title)->with('data', $data);

	}

	public function create(Request $request){
			
		 $check = $request->all();

		  unset( $check[ '_token' ] );

		  $check['slug'] = Posts::checkSlug( $check['slug'] );

		  $title = Posttypes::where('post_type' , $check['post_type'] )->first();

	      $post = Posts::insert($check);

	      if( isset($check['fields']) && $check['fields'] != '' )  :

	      		Postmeta::insert($check , $post->id );
		      	
      	  endif;

      	  if( isset($check['terms']) && $check['terms'] != '' )  :

	      		TermRelations::insertorupdate($check , $post->id );
		      	
      	  endif;

	   	return redirect( asset( 'admin/list/'.$check['post_type'] ) )
	   		   ->with('success', $title->post_type_title.' Added Successfully!');

	}


	public function edit(Request $request){
		
	    $post['post_data'] = Posts::where('ID', $request->post_id)->first()->toArray();

	    $post = Postmeta::getMetaData( $post );
		
		$post = self::parsePostContent( $post );
			
		$checktax = Taxonomy::exists($post['post_data']['post_type']);

		$post['taxonomy'] = Terms::get_terms($checktax);

		return view("admin.posts.edit",['pageTitle',$post['post_data']['post_title']])->with('data', $post);


	}

	public function update(Request $request){
		
		$check = $request->all();

		$check['slug'] = Posts::checkSlug( $check['slug'] );
		
		$post = Posts::updatepost($check);

		if( isset($check['fields']) && $check['fields'] != '' )  :

	      		Postmeta::insertorupdate($check , $check['ID'] );
		      	
  	  	endif;


		return back()->with('success', ucfirst($check['post_type']).' Updated Successfully!');


	}


	public function delete(Request $request){
		
		
		Posts::where('ID',$request->id)->delete();

		Postmeta::where('post_id',$request->id)->delete();

		return back()->with('success','Item Deleted!');


	}


	public static function parsePostContent($result){

       foreach( $result as $key => $data ) :

                foreach($data as $subkey => $subdata ) :

                    if( str_contains( $subkey , 'image') ) :
                    
                        $result[$key][$subkey] = ['path' => Index::get_image_path( $subdata ) , 'id' => $subdata ];

                    endif;


                    if($subkey == 'metadata') :

                    	foreach($subdata as $metakey => $metavalue) :

                    		if( str_contains( $metakey , 'image') || str_contains( $metakey , 'video')  ) :
                    
	                        	$result[$key][$subkey][$metakey] = [

	                        											'path' => Index::get_image_path( $metavalue ) , 
                        												'id' => $metavalue 

                        											];

	                    	endif;

                		endforeach;

                	endif;

                endforeach;

        endforeach;

        return $result;
    }

}
