<?php

namespace App\Http\Controllers\AdminControllers;

use App\Http\Controllers\Controller;

use App\Models\Backend\Services;

use App\Models\Backend\Categories;

use App\Models\Backend\Employees;

use App\Models\Backend\Location;

use Illuminate\Http\Request;

use Auth;

class ServicesController extends Controller
{

    public function index(Request $request){

        $title  = 'Admin | Services';

        $data['services'] = Services::getServices();
        
        $data['services'] ? $data['services'] = $data['services']->toArray() : '';

        $data['services']['data'] = Employees::getServiceEmployees($data['services']['data']);

        $data['categories'] = Categories::all();

        $data['categories'] ? $data['categories'] = $data['categories']->toArray() : '';

        $data['employees'] = Employees::all();

        $data['employees'] ? $data['employees'] = $data['employees']->toArray() : '';

        $data['location'] = Location::all();

        $data['location'] ? $data['location'] = $data['location']->toArray() : '';

        return view("admin.services.services")->with('title' , $title)->with('data',$data);

    }

    public function create(Request $request){

        $response = Services::entry($request);

        return json_encode(['message' => 'Services Added Successfully!']);
    }

    // For Onload

    public function edit2(Request $request){

        $id = $request->id;

        $data['services'] = Services::where('service_id',$id)->first()->toArray();

        $data['categories'] = Categories::all();

        $data['categories'] ? $data['categories'] = $data['categories']->toArray() : '';

        $data['location'] = Location::all();

        $data['location'] ? $data['location'] = $data['location']->toArray() : '';

        return view('admin.services.edit2')->with('title','Edit Service')->with('data',$data);
    }

    
    // For Ajax
    
    public function edit(Request $request){

        $id = $request->id;

        $data['services'] = Services::getService($id);

        $data['categories'] = Categories::all();

        $data['categories'] ? $data['categories'] = $data['categories']->toArray() : '';

        $data['location'] = Location::all();

        $data['location'] ? $data['location'] = $data['location']->toArray() : '';
 
        $html = view('admin.services.edit')->with('data',$data)->render();

        return json_encode(['html' => $html]);
    }

    public function update(Request $request){

        $data = $request->all();

        unset($data['_token']);

        $response = Services::updateService($data);

        return json_encode(['message' => 'Service Updated!']);
    }

    // Edit Tabs Screen Change

    public function editScreen(Request $request){

        $id = $request->id;

        $data['services'] = Services::where('service_id',$id)->first()->toArray();

        $data['categories'] = Categories::all();

        $data['categories'] ? $data['categories'] = $data['categories']->toArray() : '';

        $data['employees'] = Employees::all();

        $data['employees'] ? $data['employees'] = $data['employees']->toArray() : '';

        $data['location'] = Location::all();

        $data['location'] ? $data['location'] = $data['location']->toArray() : '';

        $data['addons'] = Services::getAddons($id);

        return view('admin.services.'.$request->view )->with('data',$data);

    }


    public function addCategory(Request $request){

        $response = Categories::entry($request);

        return json_encode(['message' => 'Category Added Successfully!']);
        
    }

    public function refresh(Request $request){

        if( $request->item == 'addon' ) :

            $data = Services::where('parent_service',$request->id)->get();

            $data ? $data = $data->toArray() : '';

            $html = view('admin.services.add-on-loop', ['data' => $data])->render();

        else :

            $data = Services::getServices();

            $data ? $data = $data->toArray() : '';

            $data['data'] = Employees::getEmployees($data['data']);

            $html = '';

            $html = view('admin.services.loop', ['data' => $data])->render();

        endif;

        return json_encode(['body'=>$html]);
    }


    public function refreshCategory(Request $request){

        $data = Categories::all();

        $data ? $data = $data->toArray() : '';

        $html = view('admin.services.catloop', ['data' => $data])->render();

        return json_encode(['body'=>$html]);
    }

    
    // Filter according to category tabs

    public function filterServices(Request $request){

        $data = Services::filterServices($request);

        $data['data'] = Employees::getServiceEmployees($data['data']);

        $html = view('admin.services.loop', ['data' => $data])->render();

        return json_encode(['body'=>$html]);
    }


    public function delete(Request $request){

        $id = $request->id;

        Services::where('service_id',$id)->delete();

        return json_encode(['message' => 'Service Deleted!']);

    }
}
