<?php

use App\Http\Controllers\AdminControllers\DashboardController;
use App\Http\Controllers\AdminControllers\PropertyController;
use App\Http\Controllers\AdminControllers\ServicesController;
use App\Http\Controllers\AdminControllers\EmployeeController;
use App\Http\Controllers\AdminControllers\MediaController;
use App\Http\Controllers\AdminControllers\CustomerController;
use App\Http\Controllers\AdminControllers\LocationController;
use App\Http\Controllers\AdminControllers\AppointmentsController;

Route::get('/phpinfo', function () { phpinfo(); });

    // Customers


Route::group(['namespace' => 'AdminControllers', 'middleware' => 'auth'], function () {

    Route::post('/checkLogin', 'AdminController@checkLogin');

    Route::fallback(function () {

        $title = '404';
        
        return view('web.404',['title'=>$title])->with('exeption','404');
        
    });


    Route::get('/dashboard', [DashboardController::class, 'dashboard']);

    Route::get('/calendar', [DashboardController::class, 'calendar']);


   // Media Routes

    Route::group(['prefix' => '/media', 'middleware' => 'auth', 'namespace' => 'AdminControllers'], function () {

        Route::post('/uploadimage',[MediaController::class, 'fileUpload']);

    });

    //Customer

    Route::group(['prefix' => '/customers', 'middleware' => 'auth', 'namespace' => 'AdminControllers'], function () {

        Route::get('/', [CustomerController::class, 'index']);

        Route::post('/add', [CustomerController::class, 'create']);

        Route::post('/edit', [CustomerController::class, 'edit']);

        Route::post('/update', [CustomerController::class, 'update']);

        Route::get('/edit/{id}', [CustomerController::class, 'edit2']);

        Route::get('/delete', [CustomerController::class, 'delete']);

        Route::post('/refresh', [CustomerController::class, 'refresh']);

    });


    // Location


    Route::group(['prefix' => '/location', 'middleware' => 'auth', 'namespace' => 'AdminControllers'], function () {

        Route::get('/', [LocationController::class, 'index']);

        Route::post('/add', [LocationController::class, 'create']);

        Route::post('/edit', [LocationController::class, 'edit']);

        Route::post('/update', [LocationController::class, 'update']);

        Route::get('/edit/{id}', [LocationController::class, 'edit2']);

        Route::get('/delete', [LocationController::class, 'delete']);

        Route::post('/refresh', [LocationController::class, 'refresh']);

    });


     // Appointments


    Route::group(['prefix' => '/appointments', 'middleware' => 'auth', 'namespace' => 'AdminControllers'], function () {

        Route::get('/', [AppointmentsController::class, 'index']);

        Route::post('/add', [AppointmentsController::class, 'create']);

        Route::post('/edit', [AppointmentsController::class, 'edit']);

        Route::post('/update', [AppointmentsController::class, 'update']);

        Route::get('/edit/{id}', [AppointmentsController::class, 'edit2']);

        Route::get('/delete', [AppointmentsController::class, 'delete']);

        Route::post('/refresh', [AppointmentsController::class, 'refresh']);

    });


    // Property Type

    Route::group(['prefix' => '/property-type', 'middleware' => 'auth', 'namespace' => 'AdminControllers'], function () {

        Route::get('/', [PropertyController::class, 'index']);

        Route::post('/add', [PropertyController::class, 'create']);

        Route::post('/edit', [PropertyController::class, 'edit']);

        Route::post('/update', [PropertyController::class, 'update']);

        Route::get('/edit/{id}', [PropertyController::class, 'edit2']);

        Route::get('/delete', [PropertyController::class, 'delete']);

        Route::post('/refresh', [PropertyController::class, 'refresh']);

    });
    
    // Services

    Route::group(['prefix' => '/services', 'middleware' => 'auth', 'namespace' => 'AdminControllers'], function () {

        Route::get('/', [ServicesController::class, 'index']);

        Route::post('/add', [ServicesController::class, 'create']);

        Route::post('/edit', [ServicesController::class, 'edit']);

        Route::post('/update', [ServicesController::class, 'update']);
        
        Route::get('/edit/{id}', [ServicesController::class, 'edit2']);

        Route::post('/edit-screen', [ServicesController::class, 'editScreen']);

        Route::post('/refresh/{item}/{id}', [ServicesController::class, 'refresh']);

        Route::get('/delete', [ServicesController::class, 'delete']);
        
        Route::post('/category/add', [ServicesController::class, 'addCategory']);

        Route::post('/category/filter', [ServicesController::class, 'filterServices']);

        Route::post('/category/refresh', [ServicesController::class, 'refreshCategory']);

    });


    // Employees

    Route::group(['prefix' => '/employees', 'middleware' => 'auth', 'namespace' => 'AdminControllers'], function () {

        Route::get('/', [EmployeeController::class, 'index']);

        Route::post('/add', [EmployeeController::class, 'create']);

        Route::post('/edit', [EmployeeController::class, 'edit']);

        Route::get('/edit/{id}', [EmployeeController::class, 'edit2']);

        Route::post('/update', [EmployeeController::class, 'update']);

        Route::get('/delete', [EmployeeController::class, 'delete']);
        
        Route::post('/refresh', [EmployeeController::class, 'refresh']);

        Route::post('/edit-screen', [EmployeeController::class, 'editScreen']);

        Route::post('/update/hours', [EmployeeController::class, 'updateHours']);

    });

        // Settings Routes
    Route::get('/setting', 'SiteSettingController@setting');

    Route::post('/updateSetting', 'SiteSettingController@updateSetting');

    

        //Pages Routes
    Route::get('/webpages', 'PagesController@webpages');

    Route::get('/addwebpage', 'PagesController@addwebpage');

    Route::post('/addnewwebpage', 'PagesController@addnewwebpage');

    Route::get('/editwebpage/{id}', 'PagesController@editwebpage');

    Route::post('/updatewebpage', 'PagesController@updatewebpage');

    Route::post('/deletepage', 'PagesController@deletepage');

    Route::get('/pageWebStatus', 'PagesController@pageWebStatus');



        //Post Type Routes

    Route::get('/list/{post_type}/', 'PostsController@view');

    Route::get('/add/{post_type}/', 'PostsController@add');

    Route::post('/create/{post_type}/', 'PostsController@create');

    Route::get('/edit/{post_id}/', 'PostsController@edit');

    Route::post('/update/{post_id}/', 'PostsController@update');

    Route::post('/deletepost', 'PostsController@delete');



        //Taxonomy Routes
    Route::get('/taxonomy/{slug}/', 'TaxonomyController@view');

    Route::post('/taxonomy/create/', 'TaxonomyController@create');

    Route::post('/taxonomy/delete/', 'TaxonomyController@delete');

    Route::post('/taxonomy/update/', 'TaxonomyController@update');

});





Route::group(['prefix' => '/admin', 'middleware' => 'auth', 'namespace' => 'AdminControllers'], function () {

    Route::get('/profile', 'AdminController@profile');
    
    Route::post('/update', 'AdminController@update');
    
    Route::post('/updatepassword', 'AdminController@updatepassword');
});

    //set sections end
